/* Generic context menu styles */
.contextMenu {
  position: absolute;
	width: 200px;
	z-index: 99999;
	border: solid 1px #CCC;
	background: #ffffff;
	padding: 0px;
	margin: 0px;
	display: none;
  box-shadow: 2px 2px 6px rgba(0,0,0,.2);
}

.contextMenu LI {
	list-style: none;
	padding: 0px;
	margin: 0px;
  border: none;
}

.contextMenu A {
	color: #333;
	text-decoration: none;
	display: block;
	line-height: 20px;
	height: 20px;
	background-position: 6px center;
	background-repeat: no-repeat;
	outline: none;
	padding: 1px 5px;
	padding-left: 28px;
}

.contextMenu LI.hover A {
	color: #FFF;
	background-color: #3875D7;
}

.contextMenu LI.disabled A {
	color: #AAA;
	cursor: default;
}

.contextMenu LI.hover.disabled A {
	background-color: transparent;
}

.contextMenu LI.separator {
	border-top: solid 1px #CCC;
}

/*
	Adding Icons

	You can add icons to the context menu by adding
	classes to the respective LI element(s)
*/

.contextMenu LI.edit A { background-image: url(images/page_white_edit.png); }
.contextMenu LI.cut A { background-image: url(images/cut.png); }
.contextMenu LI.copy A { background-image: url(images/page_white_copy.png); }
.contextMenu LI.paste A { background-image: url(images/page_white_paste.png); }
.contextMenu LI.delete A { background-image: url(images/cross.png); }
.contextMenu LI.quit A { background-image: url(images/door.png); }
.contextMenu LI.newfile A { background-image: url(images/new_file.png); }
.contextMenu LI.newdir A { background-image: url(images/new_dir.png); }
.contextMenu LI.view A { background-image: url(images/mpicture.png); }
.contextMenu LI.rename A { background-image: url(images/mfile.png); }
.contextMenu LI.md5sum A { background-image: url(images/selection-select.png); }
.contextMenu LI.refresh A { background-image: url(images/refresh.png); }
.contextMenu LI.favorite A { background-image: url(images/knewstuff.png); }
.contextMenu LI.uploadfile A { background-image: url(images/upload_folder.png); }