{% extends "layout.html" %}
{% block title %}Browse webrunner workspace{% endblock %}
{% block head %}
  {{ super() }}
  <script src="{{ url_for('static', filename='js/scripts/workspace.js') }}" type="application/javascript" charset="utf-8"></script>
  <link href="{{ url_for('static', filename='css/colorbox.css', _external=False) }}" rel="stylesheet" type="text/css" media="screen" />
  <script src="{{ url_for('static', filename='js/jquery/jquery.colorbox-min.js') }}" type="application/javascript" charset="utf-8"></script>
  <link href="{{ url_for('static', filename='css/gsFileManager.css', _external=False) }}" rel="stylesheet" type="text/css" media="screen" />
  <script src="{{ url_for('static', filename='js/jquery/gsFileManager.js') }}" type="application/javascript" charset="utf-8"></script>

{% endblock %}
{% block body %}
<div id="fileNavigator" class="browser"></div>
{% endblock %}